@@ -14,7 +14,6 @@
 #include <QObject>
 
 #include <KAboutData>
-#include <KActionCollection>
 #include <KSharedConfig>
 
 class KActionCollection;
@@ -30,7 +29,7 @@ signals:
     void applicationMouseLeave();
 
 protected:
-    bool eventFilter(QObject *obj, QEvent *event) {
+    bool eventFilter(QObject *obj, QEvent *event) override {
         if (event->type() == QEvent::Leave) {
             Q_EMIT applicationMouseLeave();
             return true;
@@ -60,21 +59,17 @@ public:
     Q_INVOKABLE QUrl pathToUrl(const QString &path);
     Q_INVOKABLE QString argument(int key);
     Q_INVOKABLE void addArgument(int key, const QString &value);
-    Q_INVOKABLE QAction *action(const QString &name);
     Q_INVOKABLE QString getFileContent(const QString &file);
     Q_INVOKABLE QStringList availableGuiStyles();
     Q_INVOKABLE void setGuiStyle(const QString &style);
     Q_INVOKABLE void activateColorScheme(const QString &name);
-    Q_INVOKABLE void configureShortcuts(const QString &name = QString());
-    Q_INVOKABLE void createUserAction(const QString &text);
     Q_INVOKABLE void openDocs(const QString &page);
 
     static QString version();
     Q_INVOKABLE static bool hasYoutubeDl();
+    Q_INVOKABLE static QString youtubeDlExecutable();
     Q_INVOKABLE static bool isYoutubePlaylist(const QString &path);
     Q_INVOKABLE static QString formatTime(const double time);
-    Q_INVOKABLE static void hideCursor();
-    Q_INVOKABLE static void showCursor();
     Q_INVOKABLE static QString mimeType(const QString &file);
 
 signals:
@@ -88,15 +83,11 @@ private:
     void setupQmlSettingsTypes();
     void setupQmlContextProperties();
     void aboutApplication();
-    void setupActions(const QString &actionName);
-    void setupUserActions();
     QAbstractItemModel *colorSchemesModel();
     QApplication *m_app;
     QQmlApplicationEngine *m_engine;
     KAboutData m_aboutData;
-    KActionCollection m_collection;
     KSharedConfig::Ptr m_config;
-    KConfigGroup *m_shortcuts;
     QMap<int, QString> m_args;
     KColorSchemeManager *m_schemes;
     QString m_systemDefaultStyle;
