@@ -13,6 +13,7 @@
 #include "track.h"
 #include "tracksmodel.h"
 #include "global.h"
+#include "worker.h"
 
 #include <QCryptographicHash>
 #include <QDir>
@@ -79,7 +80,11 @@ QOpenGLFramebufferObject * MpvRenderer::createFramebufferObject(const QSize &siz
     // init mpv_gl:
     if (!obj->mpv_gl)
     {
+#if MPV_CLIENT_API_VERSION < MPV_MAKE_VERSION(2, 0)
         mpv_opengl_init_params gl_init_params{get_proc_address_mpv, nullptr, nullptr};
+#else
+        mpv_opengl_init_params gl_init_params{get_proc_address_mpv, nullptr};
+#endif
         mpv_render_param params[]{
             {MPV_RENDER_PARAM_API_TYPE, const_cast<char *>(MPV_RENDER_API_TYPE_OPENGL)},
             {MPV_RENDER_PARAM_OPENGL_INIT_PARAMS, &gl_init_params},
@@ -114,6 +119,8 @@ MpvObject::MpvObject(QQuickItem * parent)
     setProperty("screenshot-template", VideoSettings::screenshotTemplate());
     setProperty("sub-auto", "exact");
     setProperty("volume-max", "100");
+    // set ytdl_path to yt-dlp or fallback to youtube-dl
+    setProperty("script-opts", QString("ytdl_hook-ytdl_path=%1").arg(Application::youtubeDlExecutable()));
 
     mpv_observe_property(mpv, 0, "media-title", MPV_FORMAT_STRING);
     mpv_observe_property(mpv, 0, "time-pos", MPV_FORMAT_DOUBLE);
@@ -161,6 +168,8 @@ MpvObject::MpvObject(QQuickItem * parent)
             setWatchPercentage(m_secondsWatched.count() * 100 / duration);
         }
     });
+
+    connect(this, &MpvObject::syncConfigValue, Worker::instance(), &Worker::syncConfigValue);
 }
 
 MpvObject::~MpvObject()
@@ -579,7 +588,7 @@ void MpvObject::getYouTubePlaylist(const QString &path)
 
     // use youtube-dl to get the required playlist info as json
     auto ytdlProcess = new QProcess();
-    ytdlProcess->setProgram("youtube-dl");
+    ytdlProcess->setProgram(Application::youtubeDlExecutable());
     ytdlProcess->setArguments(QStringList() << "-J" << "--flat-playlist" << path);
     ytdlProcess->start();
 
@@ -658,9 +667,9 @@ void MpvObject::saveTimePosition()
     auto hash = md5(getProperty("path").toString());
     auto timePosition = getProperty("time-pos");
     auto configPath = Global::instance()->appConfigDirPath();
-    KConfig *config = new KConfig(configPath.append("/watch-later/").append(hash));
-    config->group("").writeEntry("TimePosition", timePosition);
-    config->sync();
+    configPath.append("/watch-later/").append(hash);
+
+    Q_EMIT syncConfigValue(configPath, "", "TimePosition", getProperty("time-pos"));
 }
 
 double MpvObject::loadTimePosition()
